Class: Fastlane::Actions::IonicAction
- Inherits:
-
Action
- Object
- Action
- Fastlane::Actions::IonicAction
- Defined in:
- lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb
Constant Summary collapse
- ANDROID_ARGS_MAP =
valid action params
{ keystore_path: 'keystore', keystore_password: 'storePassword', key_password: 'password', keystore_alias: 'alias', build_number: 'versionCode', min_sdk_version: 'gradleArg=-PcdvMinSdkVersion', cordova_no_fetch: 'cordovaNoFetch' }
- IOS_ARGS_MAP =
{ type: 'packageType', team_id: 'developmentTeam', provisioning_profile: 'provisioningProfile', build_flag: 'buildFlag' }
Documentation collapse
- .authors ⇒ Object
- .available_options ⇒ Object
- .category ⇒ Object
- .description ⇒ Object
- .details ⇒ Object
- .example_code ⇒ Object
- .is_supported?(platform) ⇒ Boolean
- .output ⇒ Object
Class Method Summary collapse
-
.build(params) ⇒ Object
actual building! (run step #2).
-
.check_platform(params) ⇒ Object
add platform if missing (run step #1).
- .get_android_args(params) ⇒ Object
-
.get_app_name ⇒ Object
app_name.
- .get_ios_args(params) ⇒ Object
-
.get_platform_args(params, platform_args_map) ⇒ Object
extract arguments only valid for the platform from all arguments + map action params to the cli param they will be used for.
- .run(params) ⇒ Object
-
.set_build_paths(is_release) ⇒ Object
export build paths (run step #3).
Class Method Details
.authors ⇒ Object
342 343 344 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 342 def self. ['Jan Piotrowski'] end |
.available_options ⇒ Object
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 173 def self. [ FastlaneCore::ConfigItem.new( key: :platform, env_name: "CORDOVA_PLATFORM", description: "Platform to build on. Should be either android or ios", is_string: true, default_value: '', verify_block: proc do |value| UI.user_error!("Platform should be either android or ios") unless ['', 'android', 'ios'].include? value end ), FastlaneCore::ConfigItem.new( key: :release, env_name: "CORDOVA_RELEASE", description: "Build for release if true, or for debug if false", is_string: false, default_value: true, verify_block: proc do |value| UI.user_error!("Release should be boolean") unless [false, true].include? value end ), FastlaneCore::ConfigItem.new( key: :device, env_name: "CORDOVA_DEVICE", description: "Build for device", is_string: false, default_value: true, verify_block: proc do |value| UI.user_error!("Device should be boolean") unless [false, true].include? value end ), FastlaneCore::ConfigItem.new( key: :prod, env_name: "IONIC_PROD", description: "Build for production", is_string: false, default_value: false, verify_block: proc do |value| UI.user_error!("Prod should be boolean") unless [false, true].include? value end ), FastlaneCore::ConfigItem.new( key: :type, env_name: "CORDOVA_IOS_PACKAGE_TYPE", description: "This will determine what type of build is generated by Xcode. Valid options are development, enterprise, adhoc, and appstore", is_string: true, default_value: 'appstore', verify_block: proc do |value| UI.user_error!("Valid options are development, enterprise, adhoc, and appstore.") unless ['development', 'enterprise', 'adhoc', 'appstore', 'ad-hoc', 'app-store'].include? value end ), FastlaneCore::ConfigItem.new( key: :team_id, env_name: "CORDOVA_IOS_TEAM_ID", description: "The development team (Team ID) to use for code signing", is_string: true, default_value: CredentialsManager::AppfileConfig.try_fetch_value(:team_id) ), FastlaneCore::ConfigItem.new( key: :provisioning_profile, env_name: "CORDOVA_IOS_PROVISIONING_PROFILE", description: "GUID of the provisioning profile to be used for signing", is_string: true, default_value: '' ), FastlaneCore::ConfigItem.new( key: :keystore_path, env_name: "CORDOVA_ANDROID_KEYSTORE_PATH", description: "Path to the Keystore for Android", is_string: true, default_value: '' ), FastlaneCore::ConfigItem.new( key: :keystore_password, env_name: "CORDOVA_ANDROID_KEYSTORE_PASSWORD", description: "Android Keystore password", is_string: true, default_value: '' ), FastlaneCore::ConfigItem.new( key: :key_password, env_name: "CORDOVA_ANDROID_KEY_PASSWORD", description: "Android Key password (default is keystore password)", is_string: true, default_value: '' ), FastlaneCore::ConfigItem.new( key: :keystore_alias, env_name: "CORDOVA_ANDROID_KEYSTORE_ALIAS", description: "Android Keystore alias", is_string: true, default_value: '' ), FastlaneCore::ConfigItem.new( key: :build_number, env_name: "CORDOVA_BUILD_NUMBER", description: "Sets the build number for iOS and version code for Android", optional: true, is_string: false ), FastlaneCore::ConfigItem.new( key: :browserify, env_name: "CORDOVA_BROWSERIFY", description: "Specifies whether to browserify build or not", default_value: false, is_string: false ), FastlaneCore::ConfigItem.new( key: :project, env_name: "CORDOVA_PROJECT", description: "Specifies project in multi-projects monorepo, the project is looked up by key in the projects object", default_value: false, is_string: true ), FastlaneCore::ConfigItem.new( key: :configuration, env_name: "CORDOVA_CONFIGURATION", description: "Specifies the configuration to use (for instance to manage environment in angular)", default_value: false, is_string: true ), FastlaneCore::ConfigItem.new( key: :cordova_prepare, env_name: "CORDOVA_PREPARE", description: "Specifies whether to run `ionic cordova prepare` before building", default_value: true, is_string: false ), FastlaneCore::ConfigItem.new( key: :min_sdk_version, env_name: "CORDOVA_ANDROID_MIN_SDK_VERSION", description: "Overrides the value of minSdkVersion set in AndroidManifest.xml", default_value: '', is_string: false ), FastlaneCore::ConfigItem.new( key: :cordova_no_fetch, env_name: "CORDOVA_NO_FETCH", description: "Call `cordova platform add` with `--nofetch` parameter", default_value: false, is_string: false ), FastlaneCore::ConfigItem.new( key: :build_flag, env_name: "CORDOVA_IOS_BUILD_FLAG", description: "An array of Xcode buildFlag. Will be appended on compile command", is_string: false, optional: true, default_value: [] ), FastlaneCore::ConfigItem.new( key: :cordova_build_config_file, env_name: "CORDOVA_BUILD_CONFIG_FILE", description: "Call `ionic cordova compile` with `--buildConfig=<ConfigFile>` to specify build config file path", is_string: true, optional: true, default_value: '' ) ] end |
.build(params) ⇒ Object
actual building! (run step #2)
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 98 def self.build(params) args = [params[:release] ? '--release' : '--debug'] args << '--device' if params[:device] args << '--prod' if params[:prod] args << '--browserify' if params[:browserify] if !params[:cordova_build_config_file].to_s.empty? args << "--buildConfig=#{Shellwords.escape(params[:cordova_build_config_file])}" end if !params[:project].to_s.empty? args << "--project=#{params[:project]}" end if !params[:configuration].to_s.empty? args << "--configuration=#{params[:configuration]}" end android_args = self.get_android_args(params) if params[:platform].to_s == 'android' ios_args = self.get_ios_args(params) if params[:platform].to_s == 'ios' if params[:cordova_prepare] # TODO: Remove params not allowed/used for `prepare` sh "ionic cordova prepare #{params[:platform]} --no-interactive #{args.join(' ')}" end # special handling for `build_number` param if params[:platform].to_s == 'ios' && !params[:build_number].to_s.empty? cf_bundle_version = params[:build_number].to_s Actions::UpdateInfoPlistAction.run( xcodeproj: "./platforms/ios/#{self.get_app_name}.xcodeproj", plist_path: "#{self.get_app_name}/#{self.get_app_name}-Info.plist", block: lambda { |plist| plist['CFBundleVersion'] = cf_bundle_version } ) end if params[:platform].to_s == 'ios' sh "ionic cordova compile #{params[:platform]} --no-interactive #{args.join(' ')} -- #{ios_args}" elsif params[:platform].to_s == 'android' sh "ionic cordova compile #{params[:platform]} --no-interactive #{args.join(' ')} -- -- #{android_args}" end end |
.category ⇒ Object
364 365 366 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 364 def self.category :building end |
.check_platform(params) ⇒ Object
add platform if missing (run step #1)
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 80 def self.check_platform(params) platform = params[:platform] if platform && !File.directory?("./platforms/#{platform}") if params[:cordova_no_fetch] sh "ionic cordova platform add #{platform} --no-interactive --nofetch" else sh "ionic cordova platform add #{platform} --no-interactive" end end end |
.description ⇒ Object
165 166 167 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 165 def self.description "Build your Ionic app" end |
.details ⇒ Object
169 170 171 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 169 def self.details "Easily integrate your Ionic build into a Fastlane setup" end |
.example_code ⇒ Object
350 351 352 353 354 355 356 357 358 359 360 361 362 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 350 def self.example_code [ "ionic( platform: 'ios' )", "ionic( platform: 'android', keystore_path: './staging.keystore', keystore_alias: 'alias_name', keystore_password: 'store_password' )" ] end |
.get_android_args(params) ⇒ Object
53 54 55 56 57 58 59 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 53 def self.get_android_args(params) if params[:key_password].empty? params[:key_password] = params[:keystore_password] end return self.get_platform_args(params, ANDROID_ARGS_MAP) end |
.get_app_name ⇒ Object
app_name
92 93 94 95 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 92 def self.get_app_name config = REXML::Document.new(File.open('config.xml')) return config.elements['widget'].elements['name'].first.value # TODO: Simplify!? (Check logic in cordova) end |
.get_ios_args(params) ⇒ Object
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 61 def self.get_ios_args(params) app_identifier = CredentialsManager::AppfileConfig.try_fetch_value(:app_identifier) if params[:provisioning_profile].empty? # If `match` or `sigh` were used before this, use the certificates returned from there params[:provisioning_profile] = ENV['SIGH_UUID'] || ENV["sigh_#{app_identifier}_#{params[:type].sub('-', '')}"] end if params[:type] == 'adhoc' params[:type] = 'ad-hoc' end if params[:type] == 'appstore' params[:type] = 'app-store' end return self.get_platform_args(params, IOS_ARGS_MAP) end |
.get_platform_args(params, platform_args_map) ⇒ Object
extract arguments only valid for the platform from all arguments + map action params to the cli param they will be used for
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 30 def self.get_platform_args(params, platform_args_map) platform_args = [] platform_args_map.each do |action_key, cli_param| param_value = params[action_key] # handle `build_flag` being an Array if action_key.to_s == 'build_flag' && param_value.kind_of?(Array) unless param_value.empty? param_value.each do |flag| platform_args << "--#{cli_param}=#{flag.shellescape}" end end # handle all other cases else unless param_value.to_s.empty? platform_args << "--#{cli_param}=#{param_value.shellescape}" end end end return platform_args.join(' ') end |
.is_supported?(platform) ⇒ Boolean
346 347 348 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 346 def self.is_supported?(platform) true end |
.output ⇒ Object
335 336 337 338 339 340 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 335 def self.output [ ['CORDOVA_ANDROID_RELEASE_BUILD_PATH', 'Path to the signed release APK if it was generated'], ['CORDOVA_IOS_RELEASE_BUILD_PATH', 'Path to the signed release IPA if it was generated'] ] end |
.run(params) ⇒ Object
155 156 157 158 159 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 155 def self.run(params) self.check_platform(params) self.build(params) self.set_build_paths(params[:release]) end |
.set_build_paths(is_release) ⇒ Object
export build paths (run step #3)
144 145 146 147 148 149 150 151 152 153 |
# File 'lib/fastlane/plugin/ionic_conf/actions/ionic_action.rb', line 144 def self.set_build_paths(is_release) app_name = self.get_app_name build_type = is_release ? 'release' : 'debug' ENV['CORDOVA_ANDROID_RELEASE_BUILD_PATH'] = "./platforms/android/app/build/outputs/apk/#{build_type}/app-#{build_type}.apk" ENV['CORDOVA_IOS_RELEASE_BUILD_PATH'] = "./platforms/ios/build/device/#{app_name}.ipa" # TODO: https://github.com/bamlab/fastlane-plugin-cordova/issues/7 # TODO: Set env vars that gym and Co automatically use end |